import { db } from '@/editor/indexeddb/db'
import type { LearningActivityInfo } from '@/editor/indexeddb/types'
import { useNavigate } from '@/router'
import { Card, CardList, Icon } from '@blueprintjs/core'
import { useLiveQuery } from 'dexie-react-hooks'
import { memo } from 'react'
import { getLearningActivityIcon } from '../utils'

const LearningActivitiesOverview = () => {
  const learningActivities = useLiveQuery(
    () => db.learningActivities.toArray(),
    [],
    []
  )
  const nav = useNavigate()

  return (
    <CardList>
      {learningActivities?.map((activity: LearningActivityInfo) => (
        <Card
          interactive
          key={activity.id}
          onClick={() =>
            nav(`/editor/create/activity-specification/:activityId`, {
              params: { activityId: activity.id.toString() },
            })
          }
        >
          <Icon
            icon={getLearningActivityIcon(activity)}
            style={{ marginRight: '1rem' }}
          />
          {activity.name}
        </Card>
      ))}
    </CardList>
  )
}

export default memo(LearningActivitiesOverview)
