import { db } from './db'
import type {
  EmailAddressInfo,
  EmailTemplate,
  InjectInfo,
  LearningActivityInfo,
  LearningObjectiveInfo,
  ToolInfo,
  ToolResponse,
} from './types'

// learning objectives operations
export const addLearningObjective = async (
  objective: Omit<LearningObjectiveInfo, 'id'>
) =>
  await db.transaction('rw', db.learningObjectives, async () => {
    await db.learningObjectives.add(objective)
  })

export const updateLearningObjective = async (
  objective: LearningObjectiveInfo
) => await db.learningObjectives.put(objective)

export const deleteLearningObjective = async (id: string) =>
  await db.transaction(
    'rw',
    db.learningObjectives,
    db.learningActivities,
    async () => {
      await db.learningObjectives.delete(id)
      await db.learningActivities.where({ learningObjectiveId: id }).delete()
    }
  )

// learning activities operations
export const getLearningActivityById = async (id: number) =>
  await db.learningActivities.get(id)

export const addLearningActivity = async (
  activity: Omit<LearningActivityInfo, 'id'>
) =>
  await db.transaction('rw', db.learningActivities, async () => {
    await db.learningActivities.add(activity)
  })

export const updateLearningActivity = async (activity: LearningActivityInfo) =>
  await db.learningActivities.put(activity)

export const deleteLearningActivity = async (id: number) =>
  await db.learningActivities.delete(id)

// inject info operations
export const addInjectInfo = async (injectInfo: Omit<InjectInfo, 'id'>) =>
  await db.transaction('rw', db.injectInfos, async () => {
    await db.injectInfos.add(injectInfo)
  })

export const updateInjectInfo = async (injectInfo: InjectInfo) =>
  await db.injectInfos.put(injectInfo)

export const deleteInjectInfo = async (id: number) =>
  await db.injectInfos.delete(id)

// tool operations
export const addTool = async (tool: Omit<ToolInfo, 'id'>) =>
  await db.transaction('rw', db.tools, async () => {
    const id = await db.tools.add(tool)
    return id
  })

export const updateTool = async (tool: ToolInfo) => await db.tools.put(tool)

export const deleteTool = async (id: number) =>
  await db.transaction('rw', db.tools, db.toolResponses, async () => {
    await db.tools.delete(id)
    await db.toolResponses.where({ toolId: id }).delete()
  })

// tool response operations
export const getToolResponseByActivityId = async (learningActivityId: number) =>
  await db.toolResponses.get({ learningActivityId })

export const addToolResponse = async (response: Omit<ToolResponse, 'id'>) =>
  await db.transaction('rw', db.toolResponses, async () => {
    await db.toolResponses.add(response)
  })

export const updateToolResponse = async (response: ToolResponse) =>
  await db.toolResponses.put(response)

export const deleteToolResponse = async (id: number) =>
  await db.toolResponses.delete(id)

// email address operations
export const addEmailAddress = async (address: Omit<EmailAddressInfo, 'id'>) =>
  await db.transaction('rw', db.emailAddresses, async () => {
    const id = await db.emailAddresses.add(address)
    return id
  })

export const updateEmailAddress = async (address: EmailAddressInfo) =>
  await db.emailAddresses.put(address)

export const deleteEmailAddress = async (id: string) =>
  await db.transaction('rw', db.emailAddresses, db.emailTemplates, async () => {
    await db.emailAddresses.delete(id)
    await db.emailTemplates.where({ emailAddressId: id }).delete()
  })

// email template operations
export const getEmailTemplateByActivityId = async (
  learningActivityId: number
) => await db.emailTemplates.get({ learningActivityId })

export const addEmailTemplate = async (template: Omit<EmailTemplate, 'id'>) =>
  await db.transaction('rw', db.emailTemplates, async () => {
    await db.emailTemplates.add(template)
  })

export const updateEmailTemplate = async (template: EmailTemplate) =>
  await db.emailTemplates.put(template)

export const deleteEmailTemplate = async (id: number) =>
  await db.emailTemplates.delete(id)
