import { useEffect } from 'react'
import { useGetExerciseLoopStatus } from '../queries/GetExerciseLoopStatus.generated'
import type { ExerciseLoopRunning } from '../subscriptions/ExerciseLoopStatus.generated'
import { ExerciseLoopRunningDocument } from '../subscriptions/ExerciseLoopStatus.generated'

const useExerciseSubscriptionStatus = (exerciseId?: string) => {
  const { data: dataExerciseLoop, subscribeToMore } = useGetExerciseLoopStatus({
    fetchPolicy: 'network-only',
    nextFetchPolicy: 'cache-first',
    variables: {
      exerciseId: exerciseId || '',
    },
    skip: !exerciseId,
  })

  useEffect(() => {
    if (exerciseId) {
      return subscribeToMore({
        document: ExerciseLoopRunningDocument,
        variables: { exerciseId },
        updateQuery: (prev, { subscriptionData }) => {
          const data = subscriptionData as unknown as ExerciseLoopRunning
          if (
            data.exerciseLoopRunning?.exerciseLoopRunning === undefined ||
            data.exerciseLoopRunning.exerciseLoopRunning === null
          )
            return prev
          return {
            ...prev,
            exerciseLoopRunning: data.exerciseLoopRunning.exerciseLoopRunning,
          }
        },
      })
    }
  }, [subscribeToMore, exerciseId])

  return dataExerciseLoop?.exerciseLoopRunning
}

export default useExerciseSubscriptionStatus
